@@ -44,12 +44,24 @@ class fMMS_SenderUI(hildon.Program):
 		
 		self.window = hildon.StackableWindow()
 		self.window.set_title(gettext.ldgettext('rtcom-messaging-ui', "messaging_ti_new_mms"))
+		if subject:
+			try:
+				self.window.set_title(subject)
+			except:
+				pass
 		program.add_window(self.window)
 		
 		self.window.connect("delete_event", self.quit)
+		self.attachmentFile = ""
 		
+		draftfile = False
 		if spawner != None:
 			self.spawner = spawner
+			(tonumber, message, tmpfn) = self.cont.get_draft()
+			if tmpfn != "" and tmpfn != "None" and os.path.isfile(tmpfn):
+				withfile = tmpfn
+				self.attachmentFile = tmpfn
+				draftfile = True
 		else:
 			self.spawner = self.window
 		allBox = gtk.VBox()
@@ -117,10 +129,8 @@ class fMMS_SenderUI(hildon.Program):
 		
 		pan.add_with_viewport(midBox)
 		
-		self.attachmentFile = ""
-		
 		# Copy the file to our tempdir in case sharing service removes it
-		if withfile:
+		if withfile and not draftfile:
 			filename = os.path.basename(withfile)
 			dst = "%s/%s" % (self.config.get_imgdir(), filename)
 			log.info("Copying file to: %s" % dst)
@@ -128,7 +138,11 @@ class fMMS_SenderUI(hildon.Program):
 			self.attachmentFile = dst
 			self.fromSharingService = True
 			self.fromSharingFile = dst
-			self.set_thumbnail(self.attachmentFile)
+		if withfile or draftfile:
+			try:
+				self.set_thumbnail(self.attachmentFile)
+			except:
+				log.exception("wtf: %s" % self.attachmentFile)
 
 		""" Show it all! """
 		allBox.pack_start(topHBox1, False, False)
@@ -165,7 +179,10 @@ class fMMS_SenderUI(hildon.Program):
 			gtk.main_iteration(False)	
 
 	def set_thumbnail(self, filename):
-		filetype = gnomevfs.get_mime_type(filename)
+		try:
+			filetype = gnomevfs.get_mime_type(filename)
+		except:
+			filetype = "unknown"
 		if filetype.startswith("image") or filetype.startswith("sketch"):
 			im = Image.open(filename)
 			im.thumbnail((256, 256), Image.NEAREST)
@@ -183,7 +200,10 @@ class fMMS_SenderUI(hildon.Program):
 			image = gtk.Image()
 			image.set_from_pixbuf(pixbuf)
 		else:
-			return
+			icon_theme = gtk.icon_theme_get_default()
+			pixbuf = icon_theme.load_icon("tasklaunch_file_manager", 128, 0)
+			image = gtk.Image()
+			image.set_from_pixbuf(pixbuf)
 		
 		self.imageBox.remove(self.imageBoxContent)
 		self.imageBoxContent = image
@@ -192,14 +212,12 @@ class fMMS_SenderUI(hildon.Program):
 		return
 		
 	def open_file_dialog(self, button, data=None):
-		#fsm = hildon.FileSystemModel()
-		#fcd = hildon.FileChooserDialog(self.window, gtk.FILE_CHOOSER_ACTION_OPEN, fsm)
 		# this shouldnt issue a warning according to the pymaemo mailing list, but does
 		# anyway, nfc why :(
-		# TODO: set default dir to Camera
 		#fcd = gobject.new(hildon.FileChooserDialog, self.window, action=gtk.FILE_CHOOSER_ACTION_OPEN)
 		fcd = hildon.FileChooserDialog(self.window, gtk.FILE_CHOOSER_ACTION_OPEN)
 		fcd.set_default_response(gtk.RESPONSE_OK)
+		fcd.set_transient_for(self.window)
 		folder = self.config.get_last_ui_dir()
 		if folder:
 			if os.path.isdir(folder):
@@ -214,6 +232,7 @@ class fMMS_SenderUI(hildon.Program):
 			else:
 				self.attachmentFile = fcd.get_filename()
 				self.set_thumbnail(self.attachmentFile)
+
 			folder = fcd.get_current_folder()
 			self.config.set_last_ui_dir(folder)
 			fcd.destroy()
@@ -321,7 +340,7 @@ class fMMS_SenderUI(hildon.Program):
 			if self.attachmentIsResized == True:
 				log.info("Removing temporary image: %s", attachment)
 				os.remove(attachment)
-			self.quit()
+			self.quit("clean")
 			return
 		elif status == -1:
 			self.show_system_note(msg)
@@ -337,8 +356,17 @@ class fMMS_SenderUI(hildon.Program):
 		except:
 			pass
 
-	def quit(self, *args):
+	def quit(self, args, *kargs):
+		if args != "clean":
+			to = self.eNumber.get_text()
+			tb = self.tvMessage.get_buffer()
+			message = tb.get_text(tb.get_start_iter(), tb.get_end_iter())
+			self.cont.save_draft(to, message, "")
+		else:
+			self.cont.save_draft("", "", "")
+
 		self.from_sharing_service()
+
 		if self.window == self.spawner:		
 			gtk.main_quit()
 		else:
